==> kui-web-terminal-container-v2.0.10-3.tar.gz: package/mdist/lib/view/modes/ShowOwnerButton.js <==
/*
 * Copyright 2020 IBM Corporation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import * as React from 'react';
import { Icons } from '@kui-shell/plugin-client-common';
import { i18n, encodeComponent } from '@kui-shell/core';
import { fqn } from '../../../controller/kubectl/fqn';
import { hasSingleOwnerReference } from '../../model/resource';
import { getCommandFromArgs } from '../../../lib/util/util';
const strings = i18n('plugin-kubectl');
/**
 * Extract the events
 *
 */
function command(tab, { metadata: { namespace, ownerReferences: [{ apiVersion, kind, name }] } }, args) {
    return `${getCommandFromArgs(args)} get ${fqn(apiVersion, encodeComponent(kind), encodeComponent(name), encodeComponent(namespace || 'default'))} -o yaml`;
}
/**
 * Add an Involved Object mode button
 *
 */
const mode = {
    when: hasSingleOwnerReference,
    mode: {
        mode: 'ownerReference',
        kind: 'drilldown',
        order: 90,
        label: strings('Show Owner Reference'),
        icon: React.createElement(Icons, { icon: "Up" }),
        command
    }
};
export default mode;
//# sourceMappingURL=ShowOwnerButton.js.map

==> kui-web-terminal-container-v2.3.8-5.tar.gz: package/mdist/lib/view/modes/ShowOwnerButton.js <==
/*
 * Copyright 2020 The Kubernetes Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import { i18n, encodeComponent } from '@kui-shell/core';
import { fqn } from '../../../controller/kubectl/fqn';
import { hasSingleOwnerReference } from '../../model/resource';
import { getCommandFromArgs } from '../../../lib/util/util';
const strings = i18n('plugin-kubectl');
/**
 * Extract the events
 *
 */
function command(tab, { metadata: { namespace, ownerReferences: [{ apiVersion, kind, name }] } }, args) {
    return `${getCommandFromArgs(args)} get ${fqn(apiVersion, encodeComponent(kind), encodeComponent(name), encodeComponent(namespace || 'default'))} -o yaml`;
}
/**
 * Add an Involved Object mode button
 *
 */
const mode = {
    when: hasSingleOwnerReference,
    mode: {
        mode: 'ownerReference',
        kind: 'drilldown',
        showRelatedResource: true,
        label: strings('Show Owner Reference'),
        command
    }
};
export default mode;
//# sourceMappingURL=ShowOwnerButton.js.map
